@@ -285,7 +285,10 @@ class Carousel(object):
             # No Facts edited.
             return True
         question = _('\nReally exit without saving?')
-        confirmed = confirm(question, erase_when_done=True)
+        try:
+            confirmed = confirm(question, erase_when_done=True)
+        except KeyboardInterrupt:
+            confirmed = True  # Eh?
         return confirmed
 
     def process_save_early(self):
@@ -480,7 +483,7 @@ class Carousel(object):
 
     @catch_action_exception
     @ZoneContent.Decorators.reset_showing_help
-    def cancel_command(self, event):
+    def exit_command(self, event):
         """"""
         self.confirm_exit = True
         self.enduring_edit = False
@@ -488,7 +491,7 @@ class Carousel(object):
 
     @catch_action_exception
     @ZoneContent.Decorators.reset_showing_help
-    def cancel_softly(self, event):
+    def exit_quietly(self, event):
         """"""
         # (lb): A little awkward: Meta-key combinations start with 'escape',
         # even though the user doesn't explicitly press the escape key. E.g.,
@@ -515,6 +518,7 @@ class Carousel(object):
     @catch_action_exception
     @ZoneContent.Decorators.reset_showing_help
     def save_edited_and_exit(self, event):
+        self.save_edited_and_live(event)
         # (lb): Exit Carousel, then Save. Traditional Import behavior
         # (before running save/save_edited_and_live was implemented).
         self.enduring_edit = False
