@@ -300,6 +300,16 @@ class EditsManager(object):
         if last_edits is None:
             return False
 
+        self.manage_edited_dirty_flags(edit_facts)
+
+        self.conjoined.apply_edits(edit_facts, last_edits)
+
+        # Update undo with edited Facts.
+        self.redo_undo.update_undo_altered(edit_facts)
+
+        return True
+
+    def manage_edited_dirty_flags(self, edit_facts):
         for idx, edit_fact in enumerate(edit_facts):
             # Only unmark interval-gap if this is the first fact in edit_facts,
             # which indicates user deliberately edited gap-fact; as opposed
@@ -309,13 +319,6 @@ class EditsManager(object):
             self.manage_edited_dirty_deleted(edit_fact, undelete=is_oldest_fact)
             self.manage_edited_edit_facts(edit_fact)
 
-        self.conjoined.apply_edits(edit_facts, last_edits)
-
-        # Update undo with edited Facts.
-        self.redo_undo.update_undo_altered(edit_facts)
-
-        return True
-
     def manage_edited_dirty_deleted(self, edit_fact, undelete=False):
         edit_fact.dirty_reasons.add('unsaved-fact')
         if not undelete:
@@ -473,8 +476,8 @@ class EditsManager(object):
 
     # ***
 
-    def edit_time_adjust(self, delta_time, *attrs):
-        self.time_edit.edit_time_adjust(delta_time, *attrs)
+    def edit_time_adjust(self, *args, **kwargs):
+        self.time_edit.edit_time_adjust(*args, **kwargs)
 
     # ***
 
@@ -498,29 +501,35 @@ class EditsManager(object):
 
     # ***
 
-    def jump_fact_dec(self):
+    def jump_fact_dec(self, count=1):
         """"""
-        prev_fact = self.conjoined.jump_fact_dec()
-        if prev_fact and prev_fact.dirty:
-            self.update_edited_fact(prev_fact, prev_fact.orig_fact)
+        for idx in range(count):
+            prev_fact = self.conjoined.jump_fact_dec()
+            if prev_fact is None:
+                return prev_fact
+            elif prev_fact.dirty:
+                self.update_edited_fact(prev_fact, prev_fact.orig_fact)
         return prev_fact
 
-    def jump_fact_inc(self):
+    def jump_fact_inc(self, count=1):
         """"""
-        next_fact = self.conjoined.jump_fact_inc()
-        if next_fact and next_fact.dirty:
-            self.update_edited_fact(next_fact, next_fact.orig_fact)
+        for idx in range(count):
+            next_fact = self.conjoined.jump_fact_inc()
+            if next_fact is None:
+                return next_fact
+            elif next_fact.dirty:
+                self.update_edited_fact(next_fact, next_fact.orig_fact)
         return next_fact
 
     # ***
 
-    def jump_day_dec(self):
+    def jump_day_dec(self, days=1):
         """"""
-        return self.conjoined.jump_day_dec()
+        return self.conjoined.jump_day_dec(days=days)
 
-    def jump_day_inc(self):
+    def jump_day_inc(self, days=1):
         """"""
-        return self.conjoined.jump_day_inc()
+        return self.conjoined.jump_day_inc(days=days)
 
     # ***
 
