@@ -17,6 +17,8 @@
 
 """Fact Editing Start and End Time Adjuster"""
 
+from datetime import timedelta
+
 from .redo_undo_edit import UndoRedoTuple
 
 __all__ = (
@@ -27,6 +29,7 @@ __all__ = (
 class StartEndEdit(object):
     """"""
     def __init__(self, edits_manager):
+        self.edits_manager = edits_manager
         self.controller = edits_manager.controller
         # MAYBE/2019-01-31: (lb): This class is tightly coupled.
         #  We might as well concede defeat and make this class a
@@ -40,33 +43,95 @@ class StartEndEdit(object):
 
     # ***
 
-    def edit_time_adjust(self, delta_time, *attrs):
+    def edit_time_adjust(
+        self,
+        delta_mins_or_time,
+        start_or_end,
+        end_maybe=None,
+        gap_okay=False,
+    ):
         def _edit_time_adjust():
             edit_fact = self.editable_fact()
-            edit_prev = self.time_adjust_editable_prev(edit_fact, *attrs)
-            edit_next = self.time_adjust_editable_next(edit_fact, *attrs)
+            edit_prev, edit_next = _edit_neighbors(edit_fact)
+            newest_changes = _undoable_changes(edit_fact, edit_prev, edit_next)
+            adjust_time(edit_fact, edit_prev, edit_next)
+            adjust_time_fix_overlaps(edit_fact, edit_prev, edit_next)
+            debug_log_facts('edit-time-final', edit_fact, edit_prev, edit_next)
+            post_process_edited(newest_changes)
 
-            debug_log_facts('edit-time-begin', edit_fact, edit_prev, edit_next)
+        # ***
 
-            edit_what = 'adjust-time-{}'.format(
-                delta_time.total_seconds() >= 0 and 'pos' or 'neg',
+        def _edit_neighbors(edit_fact):
+            edit_prev = self.time_adjust_editable_prev(
+                edit_fact, start_or_end, end_maybe,
             )
+            edit_next = self.time_adjust_editable_next(
+                edit_fact, start_or_end, end_maybe,
+            )
+            debug_log_facts('edit-time-begin', edit_fact, edit_prev, edit_next)
+            return edit_prev, edit_next
+
+        # ***
+
+        def _undoable_changes(edit_fact, edit_prev, edit_next):
+            try:
+                context = delta_mins_or_time.total_seconds() >= 0 and 'pos' or 'neg'
+            except AttributeError:
+                context = start_or_end
+            edit_what = 'adjust-time-{}'.format(context)
             # Get an UndoRedoTuple from a copy of the Facts we're about to edit.
             # And set UndoRedoTuple.altered to the new copies.
             newest_changes = self.redo_undo.undoable_changes(
                 edit_what, edit_fact, edit_prev, edit_next,
             )
+            return newest_changes
 
-            self.edit_time_adjust_time(edit_fact, edit_prev, delta_time, 'start', *attrs)
-            self.edit_time_adjust_time(edit_fact, edit_next, delta_time, 'end', *attrs)
+        # ***
 
+        def adjust_time(edit_fact, edit_prev, edit_next):
+            if isinstance(delta_mins_or_time, timedelta):
+                adjust_time_by_delta(edit_fact, edit_prev, edit_next)
+            else:
+                adjust_time_set_time(edit_fact, edit_prev, edit_next)
+
+        def adjust_time_by_delta(edit_fact, edit_prev, edit_next):
+            adjust_time_by_delta_apply(edit_fact, edit_prev, 'start')
+            adjust_time_by_delta_apply(edit_fact, edit_next, 'end')
+
+        def adjust_time_by_delta_apply(edit_fact, prev_or_next, apply_start_or_end):
+            # delta_mins_or_time is datetime.timedelta.
+            self.edit_time_adjust_time(
+                edit_fact,
+                prev_or_next,
+                delta_mins_or_time,
+                apply_start_or_end,
+                gap_okay,
+                start_or_end,
+                end_maybe,
+            )
+
+        def adjust_time_set_time(edit_fact, edit_prev, edit_next):
+            # delta_mins_or_time is datetime.datetime.
+            # Only one neighbor is not None, so don't try too hard.
+            neighbor = edit_prev or edit_next
+            self.edit_time_apply_time(
+                edit_fact, delta_mins_or_time, neighbor, start_or_end, gap_okay,
+            )
+
+        def adjust_time_fix_overlaps(edit_fact, edit_prev, edit_next):
+            # 2020-04-12: (lb): I haven't been in this code in a while, but
+            # seems fishy we're setting neighbor's time here and not in
+            # edit_time_apply_time.
             if edit_prev and edit_prev.end > edit_fact.start:
+                self.controller.affirm(False)  # FIXME/2020-04-12: Use case?
                 edit_prev.end = edit_fact.start
             if edit_next and edit_next.start < edit_fact.end:
+                self.controller.affirm(False)  # FIXME/2020-04-12: Use case?
                 edit_next.start = edit_fact.end
 
-            debug_log_facts('edit-time-final', edit_fact, edit_prev, edit_next)
+        # ***
 
+        def post_process_edited(newest_changes):
             # (lb): Ug, more coupling. Because we are managing the redo-undo stack
             # specially here (possibly removing the latest undo, and squishing it
             # with the new edits), we do not want to call edits_manager.apply_edits,
@@ -88,6 +153,9 @@ class StartEndEdit(object):
                 or (newest_changes.pristine == last_undo_or_newest_changes.altered)
             )
 
+            # Mark things dirty (or not).
+            self.edits_manager.manage_edited_dirty_flags(newest_changes.altered)
+
             # Create the freshest undo. It might be squished with an earlier
             # undo created by the user within DISTINCT_CHANGES_THRESHOLD ago,
             # in which case, the pristine Facts are from the previous undo.
@@ -117,6 +185,8 @@ class StartEndEdit(object):
                 newest_changes.pristine,
             )
 
+        # ***
+
         def debug_log_facts(prefix, edit_fact, edit_prev, edit_next):
             self.controller.client_logger.debug(
                 '{}\n- edit: {}\n- prev: {}\n- next: {}'.format(
@@ -127,7 +197,9 @@ class StartEndEdit(object):
                 ),
             )
 
-        return _edit_time_adjust()
+        # ***
+
+        _edit_time_adjust()
 
     # ***
 
@@ -144,7 +216,7 @@ class StartEndEdit(object):
     # ***
 
     def edit_time_adjust_time(
-        self, edit_fact, neighbor, delta_time, start_or_end, *attrs
+        self, edit_fact, neighbor, delta_time, start_or_end, gap_okay, *attrs
     ):
         if start_or_end not in attrs:
             return
@@ -163,29 +235,57 @@ class StartEndEdit(object):
         else:
             self.controller.affirm(start_or_end == 'end')
             if new_time < edit_fact.start:
+                # We apply minimum Fact width (fact_min_delta) next.
                 new_time = edit_fact.start
-
-        incrementing = delta_time.total_seconds() > 0
-        new_time = self.edit_time_check_edge(
-            new_time, neighbor, start_or_end, incrementing,
+        self.edit_time_apply_time(
+            edit_fact, new_time, neighbor, start_or_end, gap_okay,
         )
+
+    # ***
+
+    def edit_time_apply_time(
+        self, edit_fact, new_time, neighbor, start_or_end, gap_okay=False,
+    ):
+        new_time = self.edit_time_check_edge(new_time, neighbor, start_or_end, gap_okay)
         setattr(edit_fact, start_or_end, new_time)
 
-    def edit_time_check_edge(self, new_time, neighbor, start_or_end, incrementing):
+    # ***
+
+    def edit_time_check_edge(self, new_time, neighbor, start_or_end, gap_okay=False):
         if neighbor is None:
             return new_time
+
+        # FIXME/2020-04-12: (lb): Split fact_min_delta in two? There's the
+        # "this is minimum width to save Fact", which I (personally) want
+        # 0 (or at least < 1 second). But then there's also this version,
+        # "do not automatically squash an out-of-view neighbor Fact to 0!"
+        # Let's at least ensure a 1 second minimum squash neighbor width.
+        fact_min_delta = 0
+        if 'interval-gap' not in neighbor.dirty_reasons:
+            fact_min_delta = int(self.controller.config['time.fact_min_delta'])
+            fact_min_delta = max(fact_min_delta, 1)
+        min_delta = timedelta(minutes=fact_min_delta)
+
         if start_or_end == 'start':
-            if new_time < neighbor.start:
-                self.controller.affirm(not incrementing)
-                new_time = neighbor.start
-            neighbor.end = new_time
+            end_boundary = neighbor.start + min_delta
+            if neighbor.end and end_boundary > neighbor.end:
+                # Ignore min_delta if time window already smaller.
+                end_boundary = neighbor.end
+            if new_time < end_boundary:
+                new_time = end_boundary
+            if not gap_okay or new_time < neighbor.end:
+                neighbor.end = new_time
         else:
             self.controller.affirm(start_or_end == 'end')
-            if neighbor.end and new_time > neighbor.end:
-                self.controller.affirm(incrementing)
-                new_time = neighbor.end
-                self.controller.affirm(neighbor.start == neighbor.end)
-            else:
+            if neighbor.end:
+                start_boundary = neighbor.end - min_delta
+                if start_boundary < neighbor.start:
+                    # Ignore min_delta if time window already smaller.
+                    start_boundary = neighbor.start
+                if new_time > start_boundary:
+                    new_time = start_boundary
+            if not gap_okay or new_time > neighbor.start:
                 neighbor.start = new_time
+
         return new_time
 
